==> haskell-statistics-0.14.0.2-49-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-YK33e0AeKb6IhnyPDApqw
key: statistics-0.14.0.2-YK33e0AeKb6IhnyPDApqw
license: BSD-2-Clause
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
abi: b4c79d82cf1fdf81039a23202c86a6a0
exposed: True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-YK33e0AeKb6IhnyPDApqw
depends:
    aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO base-4.11.1.0
    base-orphans-0.7-8MTyiX91Uv15VEKaJjSOuz binary-0.8.5.1
    deepseq-1.4.3.0 erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS
    math-functions-0.2.1.0-8ICtFFT4JzI19SLgPd8z0g
    monad-par-0.3.4.8-KusFSzfQ64ZKb2OBEqXCdc
    mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.7.0.1-EyyozaUjs08KrqwZf8niHA
    vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO=63ce14baf2a7c28abbc692d9e7dd92cc
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.7-8MTyiX91Uv15VEKaJjSOuz=a151edfe29dad74bae61a4558d90a63b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS=8e3912e1d1724c98e62b099f34079dd1
             math-functions-0.2.1.0-8ICtFFT4JzI19SLgPd8z0g=71a6401caf04086dd5d11a346b1f049c
             monad-par-0.3.4.8-KusFSzfQ64ZKb2OBEqXCdc=6095570c031d4a57972a392fbbb8be5c
             mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t=1ccdcd26e1b55ed9aecc3db0033b07c7
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-algorithms-0.7.0.1-EyyozaUjs08KrqwZf8niHA=c6f4ab7d39d7adcdfd0e34015c127d30
             vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw=8f69a3d65bc98dbbc58625401f1b4c42
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.14.0.2-62-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-8KBR5GskLtc2i61W9B2NKy
key: statistics-0.14.0.2-8KBR5GskLtc2i61W9B2NKy
license: BSD-2-Clause
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
abi: 59dafb34f626d5e4f654124970ed0684
exposed: True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-8KBR5GskLtc2i61W9B2NKy
depends:
    aeson-1.3.1.1-AXgHZuIctxnFM9yj6fGKmb base-4.11.1.0
    base-orphans-0.8-K0rU8s5ksIBEF74SEhusR2 binary-0.8.5.1
    deepseq-1.4.3.0 erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS
    math-functions-0.3.0.1-Cz7q884hhgc8ZHwZgpMFZJ
    monad-par-0.3.4.8-4nUgbmGcATB8dvUeNFTlXh
    mwc-random-0.14.0.0-4vkPmaLMizhfhWgfiCDmx
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.7.0.1-EyyozaUjs08KrqwZf8niHA
    vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: aeson-1.3.1.1-AXgHZuIctxnFM9yj6fGKmb=1a0b471e50c15f7e577ddfc096bd1a75
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-K0rU8s5ksIBEF74SEhusR2=d7009d493fbbbdb868729a078804cac1
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS=8e3912e1d1724c98e62b099f34079dd1
             math-functions-0.3.0.1-Cz7q884hhgc8ZHwZgpMFZJ=661a24cc8f9e588368cf65c455d296a4
             monad-par-0.3.4.8-4nUgbmGcATB8dvUeNFTlXh=0a34372a8c92e6b0986c86d0b3a83cda
             mwc-random-0.14.0.0-4vkPmaLMizhfhWgfiCDmx=6063a8a1be76823e89ed5c13c1fb4f80
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-algorithms-0.7.0.1-EyyozaUjs08KrqwZf8niHA=c6f4ab7d39d7adcdfd0e34015c127d30
             vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw=8f69a3d65bc98dbbc58625401f1b4c42
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
